Index: tests/corelib/list_set_range_test.dart |
diff --git a/tests/corelib/list_set_range_test.dart b/tests/corelib/list_set_range_test.dart |
index ad004a380564be7567a2a5b998eb00c0eceb4c91..c37e950665e33ed3762c374c9d97c8e8d40a990d 100644 |
--- a/tests/corelib/list_set_range_test.dart |
+++ b/tests/corelib/list_set_range_test.dart |
@@ -65,12 +65,12 @@ void testNegativeIndices() { |
expectIOORE(() { list.setRange(-1, 1, [1]); }); |
expectIOORE(() { list.setRange(0, 1, [1], -1); }); |
// A negative length throws an IllegalArgumentException. |
Expect.throws(() { list.setRange(0, -1, [1]); }, |
- (e) => e is IllegalArgumentException); |
+ (e) => e is ArgumentError); |
Expect.throws(() { list.setRange(-1, -1, [1], -1); }, |
- (e) => e is IllegalArgumentException); |
+ (e) => e is ArgumentError); |
Expect.listEquals([1, 2], list); |
// A zero length prevails, and does not throw an exception. |
@@ -65,12 +65,12 @@ void testNegativeIndices() { |
expectIOORE(() { list.setRange(-1, 1, [1]); }); |
expectIOORE(() { list.setRange(0, 1, [1], -1); }); |
- // A negative length throws an IllegalArgumentException. |
+ // A negative length throws an ArgumentError. |
Expect.throws(() { list.setRange(0, -1, [1]); }, |